import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CertificateAuthorityServiceResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class CaPoolsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class CertificateAuthoritiesResource(
                    googleapiclient.discovery.Resource
                ):
                    @typing.type_check_only
                    class CertificateRevocationListsResource(
                        googleapiclient.discovery.Resource
                    ):
                        def get(
                            self, *, name: str, **kwargs: typing.Any
                        ) -> CertificateRevocationListHttpRequest: ...
                        def getIamPolicy(
                            self,
                            *,
                            resource: str,
                            options_requestedPolicyVersion: int = ...,
                            **kwargs: typing.Any
                        ) -> PolicyHttpRequest: ...
                        def list(
                            self,
                            *,
                            parent: str,
                            filter: str = ...,
                            orderBy: str = ...,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            **kwargs: typing.Any
                        ) -> ListCertificateRevocationListsResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: ListCertificateRevocationListsResponseHttpRequest,
                            previous_response: ListCertificateRevocationListsResponse,
                        ) -> ListCertificateRevocationListsResponseHttpRequest | None: ...
                        def patch(
                            self,
                            *,
                            name: str,
                            body: CertificateRevocationList = ...,
                            requestId: str = ...,
                            updateMask: str = ...,
                            **kwargs: typing.Any
                        ) -> OperationHttpRequest: ...
                        def setIamPolicy(
                            self,
                            *,
                            resource: str,
                            body: SetIamPolicyRequest = ...,
                            **kwargs: typing.Any
                        ) -> PolicyHttpRequest: ...
                        def testIamPermissions(
                            self,
                            *,
                            resource: str,
                            body: TestIamPermissionsRequest = ...,
                            **kwargs: typing.Any
                        ) -> TestIamPermissionsResponseHttpRequest: ...

                    def activate(
                        self,
                        *,
                        name: str,
                        body: ActivateCertificateAuthorityRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def create(
                        self,
                        *,
                        parent: str,
                        body: CertificateAuthority = ...,
                        certificateAuthorityId: str = ...,
                        requestId: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def delete(
                        self,
                        *,
                        name: str,
                        ignoreActiveCertificates: bool = ...,
                        requestId: str = ...,
                        skipGracePeriod: bool = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def disable(
                        self,
                        *,
                        name: str,
                        body: DisableCertificateAuthorityRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def enable(
                        self,
                        *,
                        name: str,
                        body: EnableCertificateAuthorityRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def fetch(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> FetchCertificateAuthorityCsrResponseHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> CertificateAuthorityHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        orderBy: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListCertificateAuthoritiesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListCertificateAuthoritiesResponseHttpRequest,
                        previous_response: ListCertificateAuthoritiesResponse,
                    ) -> ListCertificateAuthoritiesResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: CertificateAuthority = ...,
                        requestId: str = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def undelete(
                        self,
                        *,
                        name: str,
                        body: UndeleteCertificateAuthorityRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def certificateRevocationLists(
                        self,
                    ) -> CertificateRevocationListsResource: ...

                @typing.type_check_only
                class CertificatesResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: Certificate = ...,
                        certificateId: str = ...,
                        issuingCertificateAuthorityId: str = ...,
                        requestId: str = ...,
                        validateOnly: bool = ...,
                        **kwargs: typing.Any
                    ) -> CertificateHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> CertificateHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        orderBy: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListCertificatesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListCertificatesResponseHttpRequest,
                        previous_response: ListCertificatesResponse,
                    ) -> ListCertificatesResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: Certificate = ...,
                        requestId: str = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> CertificateHttpRequest: ...
                    def revoke(
                        self,
                        *,
                        name: str,
                        body: RevokeCertificateRequest = ...,
                        **kwargs: typing.Any
                    ) -> CertificateHttpRequest: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: CaPool = ...,
                    caPoolId: str = ...,
                    requestId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, requestId: str = ..., **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def fetchCaCerts(
                    self,
                    *,
                    caPool: str,
                    body: FetchCaCertsRequest = ...,
                    **kwargs: typing.Any
                ) -> FetchCaCertsResponseHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> CaPoolHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListCaPoolsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListCaPoolsResponseHttpRequest,
                    previous_response: ListCaPoolsResponse,
                ) -> ListCaPoolsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: CaPool = ...,
                    requestId: str = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...
                def certificateAuthorities(self) -> CertificateAuthoritiesResource: ...
                def certificates(self) -> CertificatesResource: ...

            @typing.type_check_only
            class CertificateTemplatesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: CertificateTemplate = ...,
                    certificateTemplateId: str = ...,
                    requestId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, requestId: str = ..., **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> CertificateTemplateHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListCertificateTemplatesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListCertificateTemplatesResponseHttpRequest,
                    previous_response: ListCertificateTemplatesResponse,
                ) -> ListCertificateTemplatesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: CertificateTemplate = ...,
                    requestId: str = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self,
                    *,
                    name: str,
                    body: CancelOperationRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListOperationsResponseHttpRequest,
                    previous_response: ListOperationsResponse,
                ) -> ListOperationsResponseHttpRequest | None: ...

            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...
            def caPools(self) -> CaPoolsResource: ...
            def certificateTemplates(self) -> CertificateTemplatesResource: ...
            def operations(self) -> OperationsResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class CaPoolHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CaPool: ...

@typing.type_check_only
class CertificateHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Certificate: ...

@typing.type_check_only
class CertificateAuthorityHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CertificateAuthority: ...

@typing.type_check_only
class CertificateRevocationListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CertificateRevocationList: ...

@typing.type_check_only
class CertificateTemplateHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CertificateTemplate: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class FetchCaCertsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> FetchCaCertsResponse: ...

@typing.type_check_only
class FetchCertificateAuthorityCsrResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> FetchCertificateAuthorityCsrResponse: ...

@typing.type_check_only
class ListCaPoolsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCaPoolsResponse: ...

@typing.type_check_only
class ListCertificateAuthoritiesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCertificateAuthoritiesResponse: ...

@typing.type_check_only
class ListCertificateRevocationListsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCertificateRevocationListsResponse: ...

@typing.type_check_only
class ListCertificateTemplatesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCertificateTemplatesResponse: ...

@typing.type_check_only
class ListCertificatesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCertificatesResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class V2AndroidApplication(typing_extensions.TypedDict, total=False):
    packageName: str
    sha1Fingerprint: str

@typing.type_check_only
class V2AndroidKeyRestrictions(typing_extensions.TypedDict, total=False):
    allowedApplications: _list[V2AndroidApplication]

@typing.type_check_only
class V2ApiTarget(typing_extensions.TypedDict, total=False):
    methods: _list[str]
    service: str

@typing.type_check_only
class V2BrowserKeyRestrictions(typing_extensions.TypedDict, total=False):
    allowedReferrers: _list[str]

@typing.type_check_only
class V2GetKeyStringResponse(typing_extensions.TypedDict, total=False):
    keyString: str

@typing.type_check_only
class V2IosKeyRestrictions(typing_extensions.TypedDict, total=False):
    allowedBundleIds: _list[str]

@typing.type_check_only
class V2Key(typing_extensions.TypedDict, total=False):
    annotations: dict[str, typing.Any]
    createTime: str
    deleteTime: str
    displayName: str
    etag: str
    keyString: str
    name: str
    restrictions: V2Restrictions
    uid: str
    updateTime: str

@typing.type_check_only
class V2ListKeysResponse(typing_extensions.TypedDict, total=False):
    keys: _list[V2Key]
    nextPageToken: str

@typing.type_check_only
class V2LookupKeyResponse(typing_extensions.TypedDict, total=False):
    name: str
    parent: str

@typing.type_check_only
class V2Restrictions(typing_extensions.TypedDict, total=False):
    androidKeyRestrictions: V2AndroidKeyRestrictions
    apiTargets: _list[V2ApiTarget]
    browserKeyRestrictions: V2BrowserKeyRestrictions
    iosKeyRestrictions: V2IosKeyRestrictions
    serverKeyRestrictions: V2ServerKeyRestrictions

@typing.type_check_only
class V2ServerKeyRestrictions(typing_extensions.TypedDict, total=False):
    allowedIps: _list[str]

@typing.type_check_only
class V2UndeleteKeyRequest(typing_extensions.TypedDict, total=False): ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class BooksResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class BookshelvesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class VolumesResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                userId: str,
                shelf: str,
                maxResults: int = ...,
                showPreorders: bool = ...,
                source: str = ...,
                startIndex: int = ...,
                **kwargs: typing.Any
            ) -> VolumesHttpRequest: ...

        def get(
            self, *, userId: str, shelf: str, source: str = ..., **kwargs: typing.Any
        ) -> BookshelfHttpRequest: ...
        def list(
            self, *, userId: str, source: str = ..., **kwargs: typing.Any
        ) -> BookshelvesHttpRequest: ...
        def volumes(self) -> VolumesResource: ...

    @typing.type_check_only
    class CloudloadingResource(googleapiclient.discovery.Resource):
        def addBook(
            self,
            *,
            drive_document_id: str = ...,
            mime_type: str = ...,
            name: str = ...,
            upload_client_token: str = ...,
            **kwargs: typing.Any
        ) -> BooksCloudloadingResourceHttpRequest: ...
        def deleteBook(
            self, *, volumeId: str, **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def updateBook(
            self, *, body: BooksCloudloadingResource = ..., **kwargs: typing.Any
        ) -> BooksCloudloadingResourceHttpRequest: ...

    @typing.type_check_only
    class DictionaryResource(googleapiclient.discovery.Resource):
        def listOfflineMetadata(
            self, *, cpksver: str, **kwargs: typing.Any
        ) -> MetadataHttpRequest: ...

    @typing.type_check_only
    class FamilysharingResource(googleapiclient.discovery.Resource):
        def getFamilyInfo(
            self, *, source: str = ..., **kwargs: typing.Any
        ) -> FamilyInfoHttpRequest: ...
        def share(
            self,
            *,
            docId: str = ...,
            source: str = ...,
            volumeId: str = ...,
            **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def unshare(
            self,
            *,
            docId: str = ...,
            source: str = ...,
            volumeId: str = ...,
            **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...

    @typing.type_check_only
    class LayersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AnnotationDataResource(googleapiclient.discovery.Resource):
            def get(
                self,
                *,
                volumeId: str,
                layerId: str,
                annotationDataId: str,
                contentVersion: str,
                allowWebDefinitions: bool = ...,
                h: int = ...,
                locale: str = ...,
                scale: int = ...,
                source: str = ...,
                w: int = ...,
                **kwargs: typing.Any
            ) -> DictionaryAnnotationdataHttpRequest: ...
            def list(
                self,
                *,
                volumeId: str,
                layerId: str,
                contentVersion: str,
                annotationDataId: str | _list[str] = ...,
                h: int = ...,
                locale: str = ...,
                maxResults: int = ...,
                pageToken: str = ...,
                scale: int = ...,
                source: str = ...,
                updatedMax: str = ...,
                updatedMin: str = ...,
                w: int = ...,
                **kwargs: typing.Any
            ) -> AnnotationsdataHttpRequest: ...
            def list_next(
                self,
                previous_request: AnnotationsdataHttpRequest,
                previous_response: Annotationsdata,
            ) -> AnnotationsdataHttpRequest | None: ...

        @typing.type_check_only
        class VolumeAnnotationsResource(googleapiclient.discovery.Resource):
            def get(
                self,
                *,
                volumeId: str,
                layerId: str,
                annotationId: str,
                locale: str = ...,
                source: str = ...,
                **kwargs: typing.Any
            ) -> VolumeannotationHttpRequest: ...
            def list(
                self,
                *,
                volumeId: str,
                layerId: str,
                contentVersion: str,
                endOffset: str = ...,
                endPosition: str = ...,
                locale: str = ...,
                maxResults: int = ...,
                pageToken: str = ...,
                showDeleted: bool = ...,
                source: str = ...,
                startOffset: str = ...,
                startPosition: str = ...,
                updatedMax: str = ...,
                updatedMin: str = ...,
                volumeAnnotationsVersion: str = ...,
                **kwargs: typing.Any
            ) -> VolumeannotationsHttpRequest: ...
            def list_next(
                self,
                previous_request: VolumeannotationsHttpRequest,
                previous_response: Volumeannotations,
            ) -> VolumeannotationsHttpRequest | None: ...

        def get(
            self,
            *,
            volumeId: str,
            summaryId: str,
            contentVersion: str = ...,
            source: str = ...,
            **kwargs: typing.Any
        ) -> LayersummaryHttpRequest: ...
        def list(
            self,
            *,
            volumeId: str,
            contentVersion: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            source: str = ...,
            **kwargs: typing.Any
        ) -> LayersummariesHttpRequest: ...
        def annotationData(self) -> AnnotationDataResource: ...
        def volumeAnnotations(self) -> VolumeAnnotationsResource: ...

    @typing.type_check_only
    class MyconfigResource(googleapiclient.discovery.Resource):
        def getUserSettings(
            self, *, country: str = ..., **kwargs: typing.Any
        ) -> UsersettingsHttpRequest: ...
        def releaseDownloadAccess(
            self,
            *,
            cpksver: str,
            volumeIds: str | _list[str],
            locale: str = ...,
            source: str = ...,
            **kwargs: typing.Any
        ) -> DownloadAccessesHttpRequest: ...
        def requestAccess(
            self,
            *,
            cpksver: str,
            nonce: str,
            source: str,
            volumeId: str,
            licenseTypes: typing_extensions.Literal[
                "LICENSE_TYPES_UNDEFINED", "BOTH", "CONCURRENT", "DOWNLOAD"
            ] = ...,
            locale: str = ...,
            **kwargs: typing.Any
        ) -> RequestAccessDataHttpRequest: ...
        def syncVolumeLicenses(
            self,
            *,
            cpksver: str,
            nonce: str,
            source: str,
            features: typing_extensions.Literal["FEATURES_UNDEFINED", "RENTALS"]
            | _list[typing_extensions.Literal["FEATURES_UNDEFINED", "RENTALS"]] = ...,
            includeNonComicsSeries: bool = ...,
            locale: str = ...,
            showPreorders: bool = ...,
            volumeIds: str | _list[str] = ...,
            **kwargs: typing.Any
        ) -> VolumesHttpRequest: ...
        def updateUserSettings(
            self, *, body: Usersettings = ..., **kwargs: typing.Any
        ) -> UsersettingsHttpRequest: ...

    @typing.type_check_only
    class MylibraryResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AnnotationsResource(googleapiclient.discovery.Resource):
            def delete(
                self, *, annotationId: str, source: str = ..., **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def insert(
                self,
                *,
                body: Annotation = ...,
                annotationId: str = ...,
                country: str = ...,
                showOnlySummaryInResponse: bool = ...,
                source: str = ...,
                **kwargs: typing.Any
            ) -> AnnotationHttpRequest: ...
            def list(
                self,
                *,
                contentVersion: str = ...,
                layerId: str = ...,
                layerIds: str | _list[str] = ...,
                maxResults: int = ...,
                pageToken: str = ...,
                showDeleted: bool = ...,
                source: str = ...,
                updatedMax: str = ...,
                updatedMin: str = ...,
                volumeId: str = ...,
                **kwargs: typing.Any
            ) -> AnnotationsHttpRequest: ...
            def list_next(
                self,
                previous_request: AnnotationsHttpRequest,
                previous_response: Annotations,
            ) -> AnnotationsHttpRequest | None: ...
            def summary(
                self, *, layerIds: str | _list[str], volumeId: str, **kwargs: typing.Any
            ) -> AnnotationsSummaryHttpRequest: ...
            def update(
                self,
                *,
                annotationId: str,
                body: Annotation = ...,
                source: str = ...,
                **kwargs: typing.Any
            ) -> AnnotationHttpRequest: ...

        @typing.type_check_only
        class BookshelvesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class VolumesResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    shelf: str,
                    country: str = ...,
                    maxResults: int = ...,
                    projection: typing_extensions.Literal[
                        "PROJECTION_UNDEFINED", "FULL", "LITE"
                    ] = ...,
                    q: str = ...,
                    showPreorders: bool = ...,
                    source: str = ...,
                    startIndex: int = ...,
                    **kwargs: typing.Any
                ) -> VolumesHttpRequest: ...

            def addVolume(
                self,
                *,
                shelf: str,
                volumeId: str,
                reason: typing_extensions.Literal[
                    "REASON_UNDEFINED", "IOS_PREX", "IOS_SEARCH", "ONBOARDING"
                ] = ...,
                source: str = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def clearVolumes(
                self, *, shelf: str, source: str = ..., **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, shelf: str, source: str = ..., **kwargs: typing.Any
            ) -> BookshelfHttpRequest: ...
            def list(
                self, *, source: str = ..., **kwargs: typing.Any
            ) -> BookshelvesHttpRequest: ...
            def moveVolume(
                self,
                *,
                shelf: str,
                volumeId: str,
                volumePosition: int,
                source: str = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def removeVolume(
                self,
                *,
                shelf: str,
                volumeId: str,
                reason: typing_extensions.Literal[
                    "REASON_UNDEFINED", "ONBOARDING"
                ] = ...,
                source: str = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def volumes(self) -> VolumesResource: ...

        @typing.type_check_only
        class ReadingpositionsResource(googleapiclient.discovery.Resource):
            def get(
                self,
                *,
                volumeId: str,
                contentVersion: str = ...,
                source: str = ...,
                **kwargs: typing.Any
            ) -> ReadingPositionHttpRequest: ...
            def setPosition(
                self,
                *,
                volumeId: str,
                position: str,
                timestamp: str,
                action: typing_extensions.Literal[
                    "ACTION_UNDEFINED",
                    "bookmark",
                    "chapter",
                    "next-page",
                    "prev-page",
                    "scroll",
                    "search",
                ] = ...,
                contentVersion: str = ...,
                deviceCookie: str = ...,
                source: str = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...

        def annotations(self) -> AnnotationsResource: ...
        def bookshelves(self) -> BookshelvesResource: ...
        def readingpositions(self) -> ReadingpositionsResource: ...

    @typing.type_check_only
    class NotificationResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            notification_id: str,
            locale: str = ...,
            source: str = ...,
            **kwargs: typing.Any
        ) -> NotificationHttpRequest: ...

    @typing.type_check_only
    class OnboardingResource(googleapiclient.discovery.Resource):
        def listCategories(
            self, *, locale: str = ..., **kwargs: typing.Any
        ) -> CategoryHttpRequest: ...
        def listCategoryVolumes(
            self,
            *,
            categoryId: str | _list[str] = ...,
            locale: str = ...,
            maxAllowedMaturityRating: typing_extensions.Literal[
                "MAX_ALLOWED_MATURITY_RATING_UNDEFINED", "MATURE", "not-mature"
            ] = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> Volume2HttpRequest: ...
        def listCategoryVolumes_next(
            self, previous_request: Volume2HttpRequest, previous_response: Volume2
        ) -> Volume2HttpRequest | None: ...

    @typing.type_check_only
    class PersonalizedstreamResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            locale: str = ...,
            maxAllowedMaturityRating: typing_extensions.Literal[
                "MAX_ALLOWED_MATURITY_RATING_UNDEFINED", "MATURE", "not-mature"
            ] = ...,
            source: str = ...,
            **kwargs: typing.Any
        ) -> DiscoveryclustersHttpRequest: ...

    @typing.type_check_only
    class PromoofferResource(googleapiclient.discovery.Resource):
        def accept(
            self,
            *,
            androidId: str = ...,
            device: str = ...,
            manufacturer: str = ...,
            model: str = ...,
            offerId: str = ...,
            product: str = ...,
            serial: str = ...,
            volumeId: str = ...,
            **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def dismiss(
            self,
            *,
            androidId: str = ...,
            device: str = ...,
            manufacturer: str = ...,
            model: str = ...,
            offerId: str = ...,
            product: str = ...,
            serial: str = ...,
            **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def get(
            self,
            *,
            androidId: str = ...,
            device: str = ...,
            manufacturer: str = ...,
            model: str = ...,
            product: str = ...,
            serial: str = ...,
            **kwargs: typing.Any
        ) -> OffersHttpRequest: ...

    @typing.type_check_only
    class SeriesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class MembershipResource(googleapiclient.discovery.Resource):
            def get(
                self,
                *,
                series_id: str,
                page_size: int = ...,
                page_token: str = ...,
                **kwargs: typing.Any
            ) -> SeriesmembershipHttpRequest: ...

        def get(
            self, *, series_id: str | _list[str], **kwargs: typing.Any
        ) -> SeriesHttpRequest: ...
        def membership(self) -> MembershipResource: ...

    @typing.type_check_only
    class VolumesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AssociatedResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                volumeId: str,
                association: typing_extensions.Literal[
                    "ASSOCIATION_UNDEFINED",
                    "end-of-sample",
                    "end-of-volume",
                    "related-for-play",
                ] = ...,
                locale: str = ...,
                maxAllowedMaturityRating: typing_extensions.Literal[
                    "MAX_ALLOWED_MATURITY_RATING_UNDEFINED", "MATURE", "not-mature"
                ] = ...,
                source: str = ...,
                **kwargs: typing.Any
            ) -> VolumesHttpRequest: ...

        @typing.type_check_only
        class MybooksResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                acquireMethod: typing_extensions.Literal[
                    "ACQUIRE_METHOD_UNDEFINED",
                    "FAMILY_SHARED",
                    "PREORDERED",
                    "PREVIOUSLY_RENTED",
                    "PUBLIC_DOMAIN",
                    "PURCHASED",
                    "RENTED",
                    "SAMPLE",
                    "UPLOADED",
                ]
                | _list[
                    typing_extensions.Literal[
                        "ACQUIRE_METHOD_UNDEFINED",
                        "FAMILY_SHARED",
                        "PREORDERED",
                        "PREVIOUSLY_RENTED",
                        "PUBLIC_DOMAIN",
                        "PURCHASED",
                        "RENTED",
                        "SAMPLE",
                        "UPLOADED",
                    ]
                ] = ...,
                country: str = ...,
                locale: str = ...,
                maxResults: int = ...,
                processingState: typing_extensions.Literal[
                    "PROCESSING_STATE_UNDEFINED",
                    "COMPLETED_FAILED",
                    "COMPLETED_SUCCESS",
                    "RUNNING",
                ]
                | _list[
                    typing_extensions.Literal[
                        "PROCESSING_STATE_UNDEFINED",
                        "COMPLETED_FAILED",
                        "COMPLETED_SUCCESS",
                        "RUNNING",
                    ]
                ] = ...,
                source: str = ...,
                startIndex: int = ...,
                **kwargs: typing.Any
            ) -> VolumesHttpRequest: ...

        @typing.type_check_only
        class RecommendedResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                locale: str = ...,
                maxAllowedMaturityRating: typing_extensions.Literal[
                    "MAX_ALLOWED_MATURITY_RATING_UNDEFINED", "MATURE", "not-mature"
                ] = ...,
                source: str = ...,
                **kwargs: typing.Any
            ) -> VolumesHttpRequest: ...
            def rate(
                self,
                *,
                rating: typing_extensions.Literal[
                    "RATING_UNDEFINED", "HAVE_IT", "NOT_INTERESTED"
                ],
                volumeId: str,
                locale: str = ...,
                source: str = ...,
                **kwargs: typing.Any
            ) -> BooksVolumesRecommendedRateResponseHttpRequest: ...

        @typing.type_check_only
        class UseruploadedResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                locale: str = ...,
                maxResults: int = ...,
                processingState: typing_extensions.Literal[
                    "PROCESSING_STATE_UNDEFINED",
                    "COMPLETED_FAILED",
                    "COMPLETED_SUCCESS",
                    "RUNNING",
                ]
                | _list[
                    typing_extensions.Literal[
                        "PROCESSING_STATE_UNDEFINED",
                        "COMPLETED_FAILED",
                        "COMPLETED_SUCCESS",
                        "RUNNING",
                    ]
                ] = ...,
                source: str = ...,
                startIndex: int = ...,
                volumeId: str | _list[str] = ...,
                **kwargs: typing.Any
            ) -> VolumesHttpRequest: ...

        def get(
            self,
            *,
            volumeId: str,
            country: str = ...,
            includeNonComicsSeries: bool = ...,
            partner: str = ...,
            projection: typing_extensions.Literal[
                "PROJECTION_UNDEFINED", "FULL", "LITE"
            ] = ...,
            source: str = ...,
            user_library_consistent_read: bool = ...,
            **kwargs: typing.Any
        ) -> VolumeHttpRequest: ...
        def list(
            self,
            *,
            q: str,
            download: typing_extensions.Literal["DOWNLOAD_UNDEFINED", "EPUB"] = ...,
            filter: typing_extensions.Literal[
                "FILTER_UNDEFINED",
                "ebooks",
                "free-ebooks",
                "full",
                "paid-ebooks",
                "partial",
            ] = ...,
            langRestrict: str = ...,
            libraryRestrict: typing_extensions.Literal[
                "LIBRARY_RESTRICT_UNDEFINED", "my-library", "no-restrict"
            ] = ...,
            maxAllowedMaturityRating: typing_extensions.Literal[
                "MAX_ALLOWED_MATURITY_RATING_UNDEFINED", "MATURE", "not-mature"
            ] = ...,
            maxResults: int = ...,
            orderBy: typing_extensions.Literal[
                "ORDER_BY_UNDEFINED", "newest", "relevance"
            ] = ...,
            partner: str = ...,
            printType: typing_extensions.Literal[
                "PRINT_TYPE_UNDEFINED", "ALL", "BOOKS", "MAGAZINES"
            ] = ...,
            projection: typing_extensions.Literal[
                "PROJECTION_UNDEFINED", "FULL", "LITE"
            ] = ...,
            showPreorders: bool = ...,
            source: str = ...,
            startIndex: int = ...,
            **kwargs: typing.Any
        ) -> VolumesHttpRequest: ...
        def associated(self) -> AssociatedResource: ...
        def mybooks(self) -> MybooksResource: ...
        def recommended(self) -> RecommendedResource: ...
        def useruploaded(self) -> UseruploadedResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def bookshelves(self) -> BookshelvesResource: ...
    def cloudloading(self) -> CloudloadingResource: ...
    def dictionary(self) -> DictionaryResource: ...
    def familysharing(self) -> FamilysharingResource: ...
    def layers(self) -> LayersResource: ...
    def myconfig(self) -> MyconfigResource: ...
    def mylibrary(self) -> MylibraryResource: ...
    def notification(self) -> NotificationResource: ...
    def onboarding(self) -> OnboardingResource: ...
    def personalizedstream(self) -> PersonalizedstreamResource: ...
    def promooffer(self) -> PromoofferResource: ...
    def series(self) -> SeriesResource: ...
    def volumes(self) -> VolumesResource: ...

@typing.type_check_only
class AnnotationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Annotation: ...

@typing.type_check_only
class AnnotationsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Annotations: ...

@typing.type_check_only
class AnnotationsSummaryHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AnnotationsSummary: ...

@typing.type_check_only
class AnnotationsdataHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Annotationsdata: ...

@typing.type_check_only
class BooksCloudloadingResourceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BooksCloudloadingResource: ...

@typing.type_check_only
class BooksVolumesRecommendedRateResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BooksVolumesRecommendedRateResponse: ...

@typing.type_check_only
class BookshelfHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Bookshelf: ...

@typing.type_check_only
class BookshelvesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Bookshelves: ...

@typing.type_check_only
class CategoryHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Category: ...

@typing.type_check_only
class DictionaryAnnotationdataHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DictionaryAnnotationdata: ...

@typing.type_check_only
class DiscoveryclustersHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Discoveryclusters: ...

@typing.type_check_only
class DownloadAccessesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DownloadAccesses: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class FamilyInfoHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> FamilyInfo: ...

@typing.type_check_only
class LayersummariesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Layersummaries: ...

@typing.type_check_only
class LayersummaryHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Layersummary: ...

@typing.type_check_only
class MetadataHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Metadata: ...

@typing.type_check_only
class NotificationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Notification: ...

@typing.type_check_only
class OffersHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Offers: ...

@typing.type_check_only
class ReadingPositionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReadingPosition: ...

@typing.type_check_only
class RequestAccessDataHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RequestAccessData: ...

@typing.type_check_only
class SeriesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Series: ...

@typing.type_check_only
class SeriesmembershipHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Seriesmembership: ...

@typing.type_check_only
class UsersettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Usersettings: ...

@typing.type_check_only
class VolumeHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Volume: ...

@typing.type_check_only
class Volume2HttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Volume2: ...

@typing.type_check_only
class VolumeannotationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Volumeannotation: ...

@typing.type_check_only
class VolumeannotationsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Volumeannotations: ...

@typing.type_check_only
class VolumesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Volumes: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1Anomaly(
    typing_extensions.TypedDict, total=False
):
    dimensions: _list[GooglePlayDeveloperReportingV1alpha1DimensionValue]
    metric: GooglePlayDeveloperReportingV1alpha1MetricValue
    metricSet: str
    name: str
    timelineSpec: GooglePlayDeveloperReportingV1alpha1TimelineSpec

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1AnrRateMetricSet(
    typing_extensions.TypedDict, total=False
):
    freshnessInfo: GooglePlayDeveloperReportingV1alpha1FreshnessInfo
    name: str

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1CrashRateMetricSet(
    typing_extensions.TypedDict, total=False
):
    freshnessInfo: GooglePlayDeveloperReportingV1alpha1FreshnessInfo
    name: str

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1DimensionValue(
    typing_extensions.TypedDict, total=False
):
    dimension: str
    int64Value: str
    stringValue: str
    valueLabel: str

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1ErrorCountMetricSet(
    typing_extensions.TypedDict, total=False
):
    freshnessInfo: GooglePlayDeveloperReportingV1alpha1FreshnessInfo
    name: str

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1ErrorIssue(
    typing_extensions.TypedDict, total=False
):
    cause: str
    location: str
    name: str
    type: typing_extensions.Literal[
        "ERROR_TYPE_UNSPECIFIED", "APPLICATION_NOT_RESPONDING", "CRASH"
    ]

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1ErrorReport(
    typing_extensions.TypedDict, total=False
):
    issue: str
    name: str
    reportText: str
    type: typing_extensions.Literal[
        "ERROR_TYPE_UNSPECIFIED", "APPLICATION_NOT_RESPONDING", "CRASH"
    ]

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1ExcessiveWakeupRateMetricSet(
    typing_extensions.TypedDict, total=False
):
    freshnessInfo: GooglePlayDeveloperReportingV1alpha1FreshnessInfo
    name: str

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1FreshnessInfo(
    typing_extensions.TypedDict, total=False
):
    freshnesses: _list[GooglePlayDeveloperReportingV1alpha1FreshnessInfoFreshness]

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1FreshnessInfoFreshness(
    typing_extensions.TypedDict, total=False
):
    aggregationPeriod: typing_extensions.Literal[
        "AGGREGATION_PERIOD_UNSPECIFIED", "HOURLY", "DAILY"
    ]
    latestEndTime: GoogleTypeDateTime

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1ListAnomaliesResponse(
    typing_extensions.TypedDict, total=False
):
    anomalies: _list[GooglePlayDeveloperReportingV1alpha1Anomaly]
    nextPageToken: str

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1MetricValue(
    typing_extensions.TypedDict, total=False
):
    decimalValue: GoogleTypeDecimal
    metric: str

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1MetricsRow(
    typing_extensions.TypedDict, total=False
):
    aggregationPeriod: typing_extensions.Literal[
        "AGGREGATION_PERIOD_UNSPECIFIED", "HOURLY", "DAILY"
    ]
    dimensions: _list[GooglePlayDeveloperReportingV1alpha1DimensionValue]
    metrics: _list[GooglePlayDeveloperReportingV1alpha1MetricValue]
    startTime: GoogleTypeDateTime

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryAnrRateMetricSetRequest(
    typing_extensions.TypedDict, total=False
):
    dimensions: _list[str]
    filter: str
    metrics: _list[str]
    pageSize: int
    pageToken: str
    timelineSpec: GooglePlayDeveloperReportingV1alpha1TimelineSpec

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryAnrRateMetricSetResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    rows: _list[GooglePlayDeveloperReportingV1alpha1MetricsRow]

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryCrashRateMetricSetRequest(
    typing_extensions.TypedDict, total=False
):
    dimensions: _list[str]
    filter: str
    metrics: _list[str]
    pageSize: int
    pageToken: str
    timelineSpec: GooglePlayDeveloperReportingV1alpha1TimelineSpec

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryCrashRateMetricSetResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    rows: _list[GooglePlayDeveloperReportingV1alpha1MetricsRow]

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryErrorCountMetricSetRequest(
    typing_extensions.TypedDict, total=False
):
    dimensions: _list[str]
    filter: str
    metrics: _list[str]
    pageSize: int
    pageToken: str
    timelineSpec: GooglePlayDeveloperReportingV1alpha1TimelineSpec

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryErrorCountMetricSetResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    rows: _list[GooglePlayDeveloperReportingV1alpha1MetricsRow]

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryExcessiveWakeupRateMetricSetRequest(
    typing_extensions.TypedDict, total=False
):
    dimensions: _list[str]
    filter: str
    metrics: _list[str]
    pageSize: int
    pageToken: str
    timelineSpec: GooglePlayDeveloperReportingV1alpha1TimelineSpec

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryExcessiveWakeupRateMetricSetResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    rows: _list[GooglePlayDeveloperReportingV1alpha1MetricsRow]

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryStuckBackgroundWakelockRateMetricSetRequest(
    typing_extensions.TypedDict, total=False
):
    dimensions: _list[str]
    filter: str
    metrics: _list[str]
    pageSize: int
    pageToken: str
    timelineSpec: GooglePlayDeveloperReportingV1alpha1TimelineSpec

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryStuckBackgroundWakelockRateMetricSetResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    rows: _list[GooglePlayDeveloperReportingV1alpha1MetricsRow]

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1SearchErrorIssuesResponse(
    typing_extensions.TypedDict, total=False
):
    errorIssues: _list[GooglePlayDeveloperReportingV1alpha1ErrorIssue]
    nextPageToken: str

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1SearchErrorReportsResponse(
    typing_extensions.TypedDict, total=False
):
    errorReports: _list[GooglePlayDeveloperReportingV1alpha1ErrorReport]
    nextPageToken: str

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1StuckBackgroundWakelockRateMetricSet(
    typing_extensions.TypedDict, total=False
):
    freshnessInfo: GooglePlayDeveloperReportingV1alpha1FreshnessInfo
    name: str

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1TimelineSpec(
    typing_extensions.TypedDict, total=False
):
    aggregationPeriod: typing_extensions.Literal[
        "AGGREGATION_PERIOD_UNSPECIFIED", "HOURLY", "DAILY"
    ]
    endTime: GoogleTypeDateTime
    startTime: GoogleTypeDateTime

@typing.type_check_only
class GoogleTypeDateTime(typing_extensions.TypedDict, total=False):
    day: int
    hours: int
    minutes: int
    month: int
    nanos: int
    seconds: int
    timeZone: GoogleTypeTimeZone
    utcOffset: str
    year: int

@typing.type_check_only
class GoogleTypeDecimal(typing_extensions.TypedDict, total=False):
    value: str

@typing.type_check_only
class GoogleTypeTimeZone(typing_extensions.TypedDict, total=False):
    id: str
    version: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Ancestor(typing_extensions.TypedDict, total=False):
    resourceId: ResourceId

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class BooleanConstraint(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class BooleanPolicy(typing_extensions.TypedDict, total=False):
    enforced: bool

@typing.type_check_only
class ClearOrgPolicyRequest(typing_extensions.TypedDict, total=False):
    constraint: str
    etag: str

@typing.type_check_only
class CloudresourcemanagerGoogleCloudResourcemanagerV2alpha1FolderOperation(
    typing_extensions.TypedDict, total=False
):
    destinationParent: str
    displayName: str
    operationType: typing_extensions.Literal[
        "OPERATION_TYPE_UNSPECIFIED", "CREATE", "MOVE"
    ]
    sourceParent: str

@typing.type_check_only
class CloudresourcemanagerGoogleCloudResourcemanagerV2beta1FolderOperation(
    typing_extensions.TypedDict, total=False
):
    destinationParent: str
    displayName: str
    operationType: typing_extensions.Literal[
        "OPERATION_TYPE_UNSPECIFIED", "CREATE", "MOVE"
    ]
    sourceParent: str

@typing.type_check_only
class Constraint(typing_extensions.TypedDict, total=False):
    booleanConstraint: BooleanConstraint
    constraintDefault: typing_extensions.Literal[
        "CONSTRAINT_DEFAULT_UNSPECIFIED", "ALLOW", "DENY"
    ]
    description: str
    displayName: str
    listConstraint: ListConstraint
    name: str
    version: int

@typing.type_check_only
class CreateFolderMetadata(typing_extensions.TypedDict, total=False):
    displayName: str
    parent: str

@typing.type_check_only
class CreateProjectMetadata(typing_extensions.TypedDict, total=False):
    createTime: str
    gettable: bool
    ready: bool

@typing.type_check_only
class CreateTagBindingMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CreateTagKeyMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CreateTagValueMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DeleteFolderMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DeleteOrganizationMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DeleteProjectMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DeleteTagBindingMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DeleteTagKeyMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DeleteTagValueMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class FolderOperation(typing_extensions.TypedDict, total=False):
    destinationParent: str
    displayName: str
    operationType: typing_extensions.Literal[
        "OPERATION_TYPE_UNSPECIFIED", "CREATE", "MOVE"
    ]
    sourceParent: str

@typing.type_check_only
class FolderOperationError(typing_extensions.TypedDict, total=False):
    errorMessageId: typing_extensions.Literal[
        "ERROR_TYPE_UNSPECIFIED",
        "ACTIVE_FOLDER_HEIGHT_VIOLATION",
        "MAX_CHILD_FOLDERS_VIOLATION",
        "FOLDER_NAME_UNIQUENESS_VIOLATION",
        "RESOURCE_DELETED_VIOLATION",
        "PARENT_DELETED_VIOLATION",
        "CYCLE_INTRODUCED_VIOLATION",
        "FOLDER_BEING_MOVED_VIOLATION",
        "FOLDER_TO_DELETE_NON_EMPTY_VIOLATION",
        "DELETED_FOLDER_HEIGHT_VIOLATION",
    ]

@typing.type_check_only
class GetAncestryRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GetAncestryResponse(typing_extensions.TypedDict, total=False):
    ancestor: _list[Ancestor]

@typing.type_check_only
class GetEffectiveOrgPolicyRequest(typing_extensions.TypedDict, total=False):
    constraint: str

@typing.type_check_only
class GetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    options: GetPolicyOptions

@typing.type_check_only
class GetOrgPolicyRequest(typing_extensions.TypedDict, total=False):
    constraint: str

@typing.type_check_only
class GetPolicyOptions(typing_extensions.TypedDict, total=False):
    requestedPolicyVersion: int

@typing.type_check_only
class Lien(typing_extensions.TypedDict, total=False):
    createTime: str
    name: str
    origin: str
    parent: str
    reason: str
    restrictions: _list[str]

@typing.type_check_only
class ListAvailableOrgPolicyConstraintsRequest(
    typing_extensions.TypedDict, total=False
):
    pageSize: int
    pageToken: str

@typing.type_check_only
class ListAvailableOrgPolicyConstraintsResponse(
    typing_extensions.TypedDict, total=False
):
    constraints: _list[Constraint]
    nextPageToken: str

@typing.type_check_only
class ListConstraint(typing_extensions.TypedDict, total=False):
    suggestedValue: str
    supportsUnder: bool

@typing.type_check_only
class ListLiensResponse(typing_extensions.TypedDict, total=False):
    liens: _list[Lien]
    nextPageToken: str

@typing.type_check_only
class ListOrgPoliciesRequest(typing_extensions.TypedDict, total=False):
    pageSize: int
    pageToken: str

@typing.type_check_only
class ListOrgPoliciesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    policies: _list[OrgPolicy]

@typing.type_check_only
class ListPolicy(typing_extensions.TypedDict, total=False):
    allValues: typing_extensions.Literal["ALL_VALUES_UNSPECIFIED", "ALLOW", "DENY"]
    allowedValues: _list[str]
    deniedValues: _list[str]
    inheritFromParent: bool
    suggestedValue: str

@typing.type_check_only
class ListProjectsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    projects: _list[Project]

@typing.type_check_only
class MoveFolderMetadata(typing_extensions.TypedDict, total=False):
    destinationParent: str
    displayName: str
    sourceParent: str

@typing.type_check_only
class MoveProjectMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OrgPolicy(typing_extensions.TypedDict, total=False):
    booleanPolicy: BooleanPolicy
    constraint: str
    etag: str
    listPolicy: ListPolicy
    restoreDefault: RestoreDefault
    updateTime: str
    version: int

@typing.type_check_only
class Organization(typing_extensions.TypedDict, total=False):
    creationTime: str
    displayName: str
    lifecycleState: typing_extensions.Literal[
        "LIFECYCLE_STATE_UNSPECIFIED", "ACTIVE", "DELETE_REQUESTED"
    ]
    name: str
    owner: OrganizationOwner

@typing.type_check_only
class OrganizationOwner(typing_extensions.TypedDict, total=False):
    directoryCustomerId: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class Project(typing_extensions.TypedDict, total=False):
    createTime: str
    labels: dict[str, typing.Any]
    lifecycleState: typing_extensions.Literal[
        "LIFECYCLE_STATE_UNSPECIFIED",
        "ACTIVE",
        "DELETE_REQUESTED",
        "DELETE_IN_PROGRESS",
    ]
    name: str
    parent: ResourceId
    projectId: str
    projectNumber: str

@typing.type_check_only
class ProjectCreationStatus(typing_extensions.TypedDict, total=False):
    createTime: str
    gettable: bool
    ready: bool

@typing.type_check_only
class ResourceId(typing_extensions.TypedDict, total=False):
    id: str
    type: str

@typing.type_check_only
class RestoreDefault(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class SearchOrganizationsRequest(typing_extensions.TypedDict, total=False):
    filter: str
    pageSize: int
    pageToken: str

@typing.type_check_only
class SearchOrganizationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    organizations: _list[Organization]

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy
    updateMask: str

@typing.type_check_only
class SetOrgPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: OrgPolicy

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class UndeleteFolderMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UndeleteOrganizationMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UndeleteProjectMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UndeleteProjectRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UpdateFolderMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UpdateProjectMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UpdateTagKeyMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UpdateTagValueMetadata(typing_extensions.TypedDict, total=False): ...
